@@ -21,6 +21,8 @@ try:
 except ImportError as e:
     USE_STATICFILES = False
 
+from django_extensions.management.utils import signalcommand
+
 try:
     any
 except NameError:
@@ -135,12 +137,12 @@ class Command(BaseCommand):
     help = "Starts a lightweight Web server with profiling enabled."
     args = '[optional port number, or ipaddr:port]'
 
-    # Validation is called explicitly each time the server is reloaded.
-    requires_model_validation = False
-
+    @signalcommand
     def handle(self, addrport='', *args, **options):
         import django
-        from django.core.servers.basehttp import run, WSGIServerException
+        import socket
+        import errno
+        from django.core.servers.basehttp import run
         try:
             from django.core.servers.basehttp import get_internal_wsgi_application as WSGIHandler
         except ImportError:
@@ -152,6 +154,11 @@ class Command(BaseCommand):
         except ImportError:
             HAS_ADMINMEDIAHANDLER = False
 
+        try:
+            from django.core.servers.basehttp import WSGIServerException as wsgi_server_exc_cls
+        except ImportError:  # Django 1.6
+            wsgi_server_exc_cls = socket.error
+
         if args:
             raise CommandError('Usage is runserver %s' % self.args)
         if not addrport:
@@ -176,7 +183,10 @@ class Command(BaseCommand):
         def inner_run():
             import os
             import time
-            import hotshot
+            try:
+                import hotshot
+            except ImportError:
+                pass            # python 3.x
             USE_CPROFILE = options.get('use_cprofile', False)
             USE_LSPROF = options.get('use_lsprof', False)
             if USE_LSPROF:
@@ -244,7 +254,10 @@ class Command(BaseCommand):
                 return handler
 
             print("Validating models...")
-            self.validate(display_num_errors=True)
+            if hasattr(self, 'check'):
+                self.check(display_num_errors=True)
+            else:
+                self.validate(display_num_errors=True)
             print("\nDjango version %s, using settings %r" % (django.get_version(), settings.SETTINGS_MODULE))
             print("Development server is running at http://%s:%s/" % (addr, port))
             print("Quit the server with %s." % quit_command)
@@ -266,15 +279,22 @@ class Command(BaseCommand):
                         handler = StaticFilesHandler(handler)
                 handler = make_profiler_handler(handler)
                 run(addr, int(port), handler)
-            except WSGIServerException as e:
+            except wsgi_server_exc_cls as e:
                 # Use helpful error messages instead of ugly tracebacks.
                 ERRORS = {
-                    13: "You don't have permission to access that port.",
-                    98: "That port is already in use.",
-                    99: "That IP address can't be assigned-to.",
+                    errno.EACCES: "You don't have permission to access that port.",
+                    errno.EADDRINUSE: "That port is already in use.",
+                    errno.EADDRNOTAVAIL: "That IP address can't be assigned-to.",
                 }
+                if not isinstance(e, socket.error):  # Django < 1.6
+                    ERRORS[13] = ERRORS.pop(errno.EACCES)
+                    ERRORS[98] = ERRORS.pop(errno.EADDRINUSE)
+                    ERRORS[99] = ERRORS.pop(errno.EADDRNOTAVAIL)
                 try:
-                    error_text = ERRORS[e.args[0].args[0]]
+                    if not isinstance(e, socket.error):  # Django < 1.6
+                        error_text = ERRORS[e.args[0].args[0]]
+                    else:
+                        error_text = ERRORS[e.errno]
                 except (AttributeError, KeyError):
                     error_text = str(e)
                 sys.stderr.write(self.style.ERROR("Error: %s" % error_text) + '\n')
